---
title: ":rotating_light: NIGHTLY DEPENDENCIES TEST: failure on `{{ env.ref }}`"
---

The run `{{ env.run_id }}` of the workflow testing Nilearn with the nightly build of its dependencies failed on `{{ env.ref }}`.

You can view the report here: https://github.com/{{ env.repository }}/actions/runs/{{ env.run_id }}

Pinging @nilearn/core
